# Security Policy

## Supported Versions

Only the latest non-prerelease version is supported.

## Security contact information

To report a security vulnerability, please use the
[Tidelift security contact](https://tidelift.com/security). Tidelift will coordinate the
fix and disclosure.
